[nongnu] elpa/cider updated (4ecf553baf -> acea8e256d)

2022-05-04 Thread ELPA Syncer
elpasync pushed a change to branch elpa/cider.

  from  4ecf553baf Fix a changelog entry
   new  d689984274 Issue template: include Clojure CLI
   new  acea8e256d Issue template: add `JDK distribution` section


Summary of changes:
 .github/ISSUE_TEMPLATE/bug_report.md | 15 ---
 1 file changed, 12 insertions(+), 3 deletions(-)



[nongnu] elpa/helm a23bf2fa7b: Fix #2506 predicate in read-buffer

2022-05-04 Thread ELPA Syncer
branch: elpa/helm
commit a23bf2fa7b5553d2a3a8d61efa504416f876ec20
Author: Thierry Volpiatto 
Commit: Thierry Volpiatto 

Fix #2506 predicate in read-buffer

Some predicates for read-buffer assume entries in collection like
(BUF-NAME . BUF-OBJ) but helm candidates are strings, so modify
predicate so that it handles both kind of entries.
---
 helm-mode.el | 23 +++
 1 file changed, 19 insertions(+), 4 deletions(-)

diff --git a/helm-mode.el b/helm-mode.el
index 1ac8e6a4c7..9d3b1c98a8 100644
--- a/helm-mode.el
+++ b/helm-mode.el
@@ -1149,10 +1149,25 @@ Don't use it directly."
 (defun helm--generic-read-buffer (prompt &optional default require-match 
predicate)
   "The `read-buffer-function' for `helm-mode'.
 Affects `switch-to-buffer' `kill-buffer' and related."
-  (helm--completing-read-default
-   prompt (or minibuffer-completion-table
-  (internal-complete-buffer "" nil t))
-   predicate require-match nil nil default))
+  ;; `read-buffer' is using internally `Vbuffer_alist' which is an
+  ;; alist with elements like (BUF-NAME . BUF-OBJ), therefore some
+  ;; predicates in Emacs are working only on such cons cells.
+  ;; However, helm is transforming COLLECTION in a list of strings and
+  ;; such predicates are failing because they expect cons cells (see
+  ;; bug#2506 with `project-switch-to-buffer'), even if they should
+  ;; handle strings as well according to `read-buffer'
+  ;; documentation.
+  (let ((pred (when predicate
+(lambda (buffer)
+  (let ((buf (cons buffer (get-buffer buffer
+(condition-case _err
+(funcall predicate buffer)
+  (wrong-type-argument
+   (funcall predicate buf
+(helm--completing-read-default
+ prompt (or minibuffer-completion-table
+(internal-complete-buffer "" nil t))
+ pred require-match nil nil default)))
 
 (defun helm-mode--get-default-handler-for (comp-or-file entry)
   ;; Use 'comp for completing-read and 'file for 'read-file-name as



[nongnu] elpa/helm-core updated (24d6d92646 -> a23bf2fa7b)

2022-05-04 Thread ELPA Syncer
elpasync pushed a change to branch elpa/helm-core.

  from  24d6d92646 Fix wdired advice for emacs-28+
  adds  a23bf2fa7b Fix #2506 predicate in read-buffer

No new revisions were added by this update.

Summary of changes:
 helm-mode.el | 23 +++
 1 file changed, 19 insertions(+), 4 deletions(-)



[elpa] externals/sql-cassandra updated (f0daf06e19 -> e5aea0fa0b)

2022-05-04 Thread Filipp Gunbin
fgunbin pushed a change to branch externals/sql-cassandra.

  from  f0daf06e19 Require emacs 29.  Bump version.
   new  ed260c2f83 Move sql-cassandra-special-commands into eval-and-compile
   new  a1de42bd8a auto-mode-alist for .cql files
   new  e5aea0fa0b Bump version


Summary of changes:
 sql-cassandra.el | 10 +++---
 1 file changed, 7 insertions(+), 3 deletions(-)



[elpa] externals/sql-cassandra ed260c2f83 1/3: Move sql-cassandra-special-commands into eval-and-compile

2022-05-04 Thread Filipp Gunbin
branch: externals/sql-cassandra
commit ed260c2f832e3dfa8942f2fc8dd57710ead702e9
Author: Filipp Gunbin 
Commit: Filipp Gunbin 

Move sql-cassandra-special-commands into eval-and-compile
---
 sql-cassandra.el | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/sql-cassandra.el b/sql-cassandra.el
index d4aa1a0f48..2b12ab8d5a 100644
--- a/sql-cassandra.el
+++ b/sql-cassandra.el
@@ -48,7 +48,7 @@
   :group 'SQL)
 
 
-(eval-when-compile
+(eval-and-compile
   (defconst sql-cassandra-special-commands
 '("capture" "cls" "copy" "describe" "expand" "login" "serial"
   "source" "unicode" "clear" "consistency" "desc" "exit" "help"
@@ -56,8 +56,9 @@
 "Special commands recognized by cqlsh.
 
 Refer to:
-https://cassandra.apache.org/doc/latest/cassandra/tools/cqlsh.html#special-commands";)
+https://cassandra.apache.org/doc/latest/cassandra/tools/cqlsh.html#special-commands";))
 
+(eval-when-compile
   (defconst sql-cassandra-native-types
 '("ascii" "bigint" "blob" "boolean" "counter" "date" "decimal"
   "double" "duration" "float" "inet" "int" "smallint" "text" "time"



[elpa] externals/sql-cassandra e5aea0fa0b 3/3: Bump version

2022-05-04 Thread Filipp Gunbin
branch: externals/sql-cassandra
commit e5aea0fa0b45dcc07edbcda75e7dff30260a066e
Author: Filipp Gunbin 
Commit: Filipp Gunbin 

Bump version
---
 sql-cassandra.el | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/sql-cassandra.el b/sql-cassandra.el
index 9b448c26ec..23801dbbb9 100644
--- a/sql-cassandra.el
+++ b/sql-cassandra.el
@@ -5,7 +5,7 @@
 ;; Author: Filipp Gunbin 
 ;; Maintainer: Filipp Gunbin 
 ;; Package-Requires: ((emacs "29"))
-;; Version: 0.2
+;; Version: 0.21
 ;; Keywords: sql, cassandra, cql, cqlsh
 
 ;; This program is free software; you can redistribute it and/or modify



[elpa] externals/sql-cassandra a1de42bd8a 2/3: auto-mode-alist for .cql files

2022-05-04 Thread Filipp Gunbin
branch: externals/sql-cassandra
commit a1de42bd8a08ba2675de258550eea41f4fef8f51
Author: Filipp Gunbin 
Commit: Filipp Gunbin 

auto-mode-alist for .cql files
---
 sql-cassandra.el | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/sql-cassandra.el b/sql-cassandra.el
index 2b12ab8d5a..9b448c26ec 100644
--- a/sql-cassandra.el
+++ b/sql-cassandra.el
@@ -154,6 +154,9 @@ Refer to 
https://cassandra.apache.org/doc/latest/cassandra/cql/appendices.html#a
   (interactive "P")
   (sql-product-interactive 'cassandra buffer))
 
+;;;###autoload
+(add-to-list 'auto-mode-alist '("\\.cql\\'" . sql-mode))
+
 (sql-add-product
  'cassandra "Cassandra"
  :free-software t



[elpa] externals/sql-cassandra 2920f8c64e: Fix version

2022-05-04 Thread Filipp Gunbin
branch: externals/sql-cassandra
commit 2920f8c64e937904087f3636696501fb1cfe7acc
Author: Filipp Gunbin 
Commit: Filipp Gunbin 

Fix version
---
 sql-cassandra.el | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/sql-cassandra.el b/sql-cassandra.el
index 23801dbbb9..e1aec871b3 100644
--- a/sql-cassandra.el
+++ b/sql-cassandra.el
@@ -5,7 +5,7 @@
 ;; Author: Filipp Gunbin 
 ;; Maintainer: Filipp Gunbin 
 ;; Package-Requires: ((emacs "29"))
-;; Version: 0.21
+;; Version: 0.2.1
 ;; Keywords: sql, cassandra, cql, cqlsh
 
 ;; This program is free software; you can redistribute it and/or modify



[elpa] externals/javaimp 22801e7614: * javaimp.el (javaimp-add-log-current-defun): New function

2022-05-04 Thread Filipp Gunbin
branch: externals/javaimp
commit 22801e7614fd61b732458626b235e824fe28fee3
Author: Filipp Gunbin 
Commit: Filipp Gunbin 

* javaimp.el (javaimp-add-log-current-defun): New function
---
 javaimp.el | 30 +++---
 1 file changed, 27 insertions(+), 3 deletions(-)

diff --git a/lisp/org-fold.el b/lisp/org-fold.el
index 64492f6042..5085778dcd 100644
--- a/lisp/org-fold.el
+++ b/lisp/org-fold.el
@@ -1125,16 +1125,18 @@ The detailed reaction depends on the user option
 (and (not invisible-at-point) invisible-before-point
  (memq kind '(insert delete))
   (when (or invisible-at-point invisible-before-point)
-   (when (eq org-fold-catch-invisible-edits 'error)
+   (when (and (eq org-fold-catch-invisible-edits 'error)
+   (not border-and-ok-direction))
  (user-error "Editing in invisible areas is prohibited, make them 
visible first"))
(if (and org-custom-properties-overlays
 (y-or-n-p "Display invisible properties in this buffer? "))
(org-toggle-custom-properties-visibility)
  ;; Make the area visible
-  (save-excursion
-   (org-fold-show-set-visibility 'local))
-  (when invisible-before-point
-(org-with-point-at (1- (point)) (org-fold-show-set-visibility 
'local)))
+  (unless (eq org-fold-catch-invisible-edits 'error)
+(save-excursion
+ (org-fold-show-set-visibility 'local))
+(when invisible-before-point
+  (org-with-point-at (1- (point)) (org-fold-show-set-visibility 
'local
  (cond
   ((eq org-fold-catch-invisible-edits 'show)
;; That's it, we do the edit after showing
@@ -1144,6 +1146,9 @@ The detailed reaction depends on the user option
   ((and (eq org-fold-catch-invisible-edits 'smart)
 border-and-ok-direction)
(message "Unfolding invisible region around point before editing"))
+   (border-and-ok-direction
+;; Just continue editing.
+nil)
   (t
;; Don't do the edit, make the user repeat it in full visibility
(user-error "Edit in invisible region aborted, repeat to confirm 
with text visible"



[elpa] elpa-admin 3478d4c34d: * elpa-admin.el (elpaa--make-one-tarball-1): Obey .elpaignore

2022-05-04 Thread Stefan Monnier via
branch: elpa-admin
commit 3478d4c34df701a32080f0e0fdb3017c81435d8e
Author: Stefan Monnier 
Commit: Stefan Monnier 

* elpa-admin.el (elpaa--make-one-tarball-1): Obey .elpaignore

Always use `.elpaignore` rather than only when an `:ignored-files` is
 not provided.
---
 elpa-admin.el | 8 +++-
 1 file changed, 3 insertions(+), 5 deletions(-)

diff --git a/elpa-admin.el b/elpa-admin.el
index 750dbe9a98..5e991d68bc 100644
--- a/elpa-admin.el
+++ b/elpa-admin.el
@@ -627,11 +627,9 @@ auxillary files unless TARBALL-ONLY is non-nil ."
  (apply #'elpaa--call
 nil "tar"
 `("--exclude-vcs"
-  ,@(cond
- (ignores
-  (mapcar (lambda (i) (format "--exclude=packages/%s/%s" 
pkgname i))
-  ignores))
- ((file-readable-p elpaignore) `("-X" ,elpaignore)))
+  ,@(mapcar (lambda (i) (format "--exclude=packages/%s/%s" pkgname 
i))
+ignores)
+  ,@(when (file-readable-p elpaignore) `("-X" ,elpaignore))
   ,@(mapcar (lambda (r) (elpaa--make-tar-transform pkgname r))
 renames)
   "--transform"



[elpa] externals/tomelr 8fc2257ec0: chore: Bump version

2022-05-04 Thread ELPA Syncer
branch: externals/tomelr
commit 8fc2257ec072a3fc3316c7f311722db50b37558e
Author: Kaushal Modi 
Commit: Kaushal Modi 

chore: Bump version

Ref: https://lists.gnu.org/r/emacs-devel/2022-05/msg00114.html
---
 tomelr.el | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/tomelr.el b/tomelr.el
index bc6fd29ed7..7a81a82971 100644
--- a/tomelr.el
+++ b/tomelr.el
@@ -3,7 +3,7 @@
 ;; Copyright (C) 2022 Free Software Foundation, Inc.
 
 ;; Author: Kaushal Modi 
-;; Version: 0.2.4
+;; Version: 0.2.5
 ;; Package-Requires: ((emacs "26.3"))
 ;; Keywords: data, tools, toml, serialization, config
 ;; URL: https://github.com/kaushalmodi/tomelr/



[elpa] externals/buffer-env f213017cc6: Remove obsolete variable buffer-env-command

2022-05-04 Thread ELPA Syncer
branch: externals/buffer-env
commit f213017cc64017a3ed4197a6528272679c0c0612
Author: Augusto Stoffel 
Commit: Augusto Stoffel 

Remove obsolete variable buffer-env-command
---
 buffer-env.el | 17 +
 1 file changed, 5 insertions(+), 12 deletions(-)

diff --git a/buffer-env.el b/buffer-env.el
index f21a324a2f..13783df83b 100644
--- a/buffer-env.el
+++ b/buffer-env.el
@@ -61,12 +61,6 @@
   "File name of the script to produce environment variables."
   :type 'string)
 
-(defcustom buffer-env-command ">&2 . \"$0\" && env -0"
-  "Command to produce environment variables.
-This variable is obsolete.  Use `buffer-env-commands' instead."
-  :type 'string)
-(make-obsolete-variable 'buffer-env-command 'buffer-env-commands "0.3" 'set)
-
 (defcustom buffer-env-commands
   '((".env" . "set -a && >&2 . \"$0\" && env -0")
 ("guix.scm" . ">&2 guix shell -D -f \"$0\" -- env -0")
@@ -168,12 +162,11 @@ When called interactively, ask for a FILE."
(expand-file-name file)
  (buffer-env--locate-script)))
  ((buffer-env--authorize file))
- (command (or buffer-env-command
-  (seq-some (pcase-lambda (`(,patt . ,command))
-  (when (string-match-p 
(wildcard-to-regexp patt)
-
(file-name-nondirectory file))
-command))
-buffer-env-commands)))
+ (command (seq-some (pcase-lambda (`(,patt . ,command))
+  (when (string-match-p (wildcard-to-regexp 
patt)
+
(file-name-nondirectory file))
+command))
+buffer-env-commands))
  (vars (with-temp-buffer
  (let* ((default-directory (file-name-directory file))
 (message-log-max nil)



[elpa] externals/kind-icon 03a40826d6: autoloads

2022-05-04 Thread ELPA Syncer
branch: externals/kind-icon
commit 03a40826d6ce576e3b8ac64c528b9fe57e08101b
Author: JD Smith <93749+jdtsm...@users.noreply.github.com>
Commit: JD Smith <93749+jdtsm...@users.noreply.github.com>

autoloads
---
 kind-icon.el | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/kind-icon.el b/kind-icon.el
index 52ee5917ad..f1f4edb137 100644
--- a/kind-icon.el
+++ b/kind-icon.el
@@ -280,6 +280,7 @@ background-color."
  (propertize (concat pad-left "??" pad-right) 'face 
font-lock-warning-face)))
kind-icon--unknown)))
 
+;;;###autoload
 (defun kind-icon-margin-formatter (metadata)
   "Return a margin-formatter function which produces kind icons.
 METADATA is the completion metadata supplied by the caller (see
@@ -312,6 +313,7 @@ and its result used as the affixation suffix, first setting 
the
  suffix
  candidates)))
 
+;;;###autoload
 (defun kind-icon-enhance-completion (completion-function)
 "A wrapper for completion-in-region-functions.
 This wrapper sets a custom affixation-function which places an



[elpa] externals/javaimp b7a5b1a649: javaimp-show-scopes: Use markers. Add javaimp-show-scopes-revert.

2022-05-04 Thread Filipp Gunbin
branch: externals/javaimp
commit b7a5b1a649b9ab0d2bd3d2477d90e0003ab5407e
Author: Filipp Gunbin 
Commit: Filipp Gunbin 

javaimp-show-scopes: Use markers.  Add javaimp-show-scopes-revert.
---
 javaimp.el | 102 +
 1 file changed, 62 insertions(+), 40 deletions(-)

diff --git a/javaimp.el b/javaimp.el
index 455033bdb0..d4ae6b7bdd 100644
--- a/javaimp.el
+++ b/javaimp.el
@@ -818,7 +818,6 @@ in a major mode hook."
 map)
   "Javaimp Show Scopes keymap.")
 
-;; TODO handle mouse-1
 (defun javaimp-show-scopes-goto-scope (event &optional to-start)
   "Go to the opening brace (`javaimp-scope-open-brace') of the scope.
 Target scope is determined by location of mouse EVENT, if it's
@@ -826,55 +825,78 @@ non-nil.  Else, take the scope at current line.  When 
TO-START is
 non-nil, go to scope start (`javaimp-scope-start') instead of the
 opening brace."
   (interactive (list last-nonmenu-event current-prefix-arg))
-  (let ((buf (current-buffer))
-(scopes-buf-pos
- (if event
- (cons (window-buffer (posn-window (event-end event)))
-   (posn-point (event-end event)))
-   (cons (current-buffer)
- (point
-source-file scope)
-(with-current-buffer (car scopes-buf-pos)
-  (setq source-file
-(get-text-property (point-min) 'javaimp-show-scopes-file)
-scope
-(get-text-property (cdr scopes-buf-pos) 
'javaimp-show-scopes-scope)))
-(unless (and source-file scope)
-  (user-error "No target scope"))
-(pop-to-buffer (find-file-noselect source-file))
-(goto-char (if to-start
-   (javaimp-scope-start scope)
- (javaimp-scope-open-brace scope)))
+  (let* ((buf (current-buffer))
+ (scopes-buf (if event
+ (window-buffer (posn-window (event-end event)))
+   (current-buffer)))
+ (scopes-pos (if event
+ (posn-point (event-end event))
+   (point)))
+ (markers (or (with-current-buffer scopes-buf
+(get-text-property scopes-pos 
'javaimp-show-scopes-markers))
+  (user-error "No scope on this line")))
+ (marker (if to-start
+ (cadr markers)
+   (car markers
+(unless (buffer-live-p (marker-buffer marker))
+  (user-error "Buffer for this scope was killed"))
+(pop-to-buffer (marker-buffer marker))
+(goto-char marker)
 (next-error-found buf (current-buffer
 
-
 (put 'javaimp-show-scopes-mode 'mode-class 'special)
 (define-derived-mode javaimp-show-scopes-mode special-mode "Javaimp Show 
Scopes"
+  (setq-local revert-buffer-function #'javaimp-show-scopes-revert)
   (setq next-error-function #'javaimp-show-scopes-next-error))
 
 (defun javaimp-show-scopes ()
   "Show scopes in *javaimp-scopes* buffer."
   (interactive)
+  (display-buffer
+   (javaimp-show-scopes-1 (current-buffer
+
+(defun javaimp-show-scopes-revert (_ignore1 _ignore2)
+  "Function to be used as `revert-buffer-function' in
+`javaimp-show-scopes-mode' buffers."
+  (let ((source-buf
+ (get-file-buffer
+  (get-text-property (point-min) 'javaimp-show-scopes-file
+(if source-buf
+(javaimp-show-scopes-1 source-buf)
+  (user-error "Source buffer has been killed"
+
+(defun javaimp-show-scopes-1 (source-buf)
+  "Subroutine of `javaimp-show-scopes', outputs scopes from
+SOURCE-BUF in *javaimp-scopes* buffer.  Returns resulting
+buffer."
   (let ((scopes
- (save-excursion
-   (save-restriction
- (widen)
- (javaimp-parse-get-all-scopes
-  nil nil (javaimp-scope-defun-p '(method anon-class))
-(source-buf (current-buffer))
-(source-default-dir default-directory)
+ (with-current-buffer source-buf
+   (save-excursion
+ (save-restriction
+   (widen)
+   (javaimp-parse-get-all-scopes
+nil nil (javaimp-scope-defun-p '(method anon-class)))
+(default-dir
+ (with-current-buffer source-buf
+   default-directory))
 (buf (get-buffer-create "*javaimp-scopes*")))
 (with-current-buffer buf
-  (setq default-directory source-default-dir)
+  (setq default-directory default-dir)
   (javaimp-show-scopes-mode)
   (let ((inhibit-read-only t)
 (buffer-undo-list t))
 (erase-buffer)
-(insert (propertize (format "%s\n\n" (buffer-file-name source-buf))
-'javaimp-show-scopes-file (buffer-file-name 
source-buf)))
+(insert (propertize (format "%s" (buffer-file-name source-buf))
+'javaimp-show-scopes-file (buffer-file-name 
source-buf))
+"\n\n")
 (dolist (scope scopes)
   (let ((depth 0)
-(tmp scope

[elpa] externals/javaimp 6c394541ed: javaimp-show-scopes: Add binding for revert-buffer

2022-05-04 Thread Filipp Gunbin
branch: externals/javaimp
commit 6c394541ed2734732d8075a119f412cbc046fdcc
Author: Filipp Gunbin 
Commit: Filipp Gunbin 

javaimp-show-scopes: Add binding for revert-buffer
---
 javaimp.el | 1 +
 1 file changed, 1 insertion(+)

diff --git a/javaimp.el b/javaimp.el
index d4ae6b7bdd..1809dd426d 100644
--- a/javaimp.el
+++ b/javaimp.el
@@ -812,6 +812,7 @@ in a major mode hook."
 (set-keymap-parent map text-mode-map)
 (define-key map "\C-m" #'javaimp-show-scopes-goto-scope)
 (define-key map [mouse-2] #'javaimp-show-scopes-goto-scope)
+(define-key map "g" #'revert-buffer)
 (define-key map "n" #'next-error-no-select)
 (define-key map "p" #'previous-error-no-select)
 (define-key map "l" #'recenter-current-error)



[nongnu] elpa/evil 6c5079b105: Make sure not to test stale code (#1619)

2022-05-04 Thread ELPA Syncer
branch: elpa/evil
commit 6c5079b105b2ccbcfa735fd1b6a19797daa7081d
Author: rbrtb <104695105+rb...@users.noreply.github.com>
Commit: GitHub 

Make sure not to test stale code (#1619)

When there's outdate byte-compiled files, they may be loaded instead
of the new changed code.
Enable `load-prefer-newer` would avoid this.
---
 evil-tests.el | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/evil-tests.el b/evil-tests.el
index 5aa9013831..d38ee9ea50 100644
--- a/evil-tests.el
+++ b/evil-tests.el
@@ -61,6 +61,8 @@
 ;;
 ;; This file is NOT part of Evil itself.
 
+(setq load-prefer-newer t)
+
 (require 'cl-lib)
 (require 'elp)
 (require 'ert)



[elpa] externals/embark ac79525732: Initial version of embark-org

2022-05-04 Thread ELPA Syncer
branch: externals/embark
commit ac7952573272d05f150917cfeab6d0a4cef39a9a
Author: Omar Antolín 
Commit: Omar Antolín 

Initial version of embark-org
---
 embark-org.el | 240 ++
 1 file changed, 240 insertions(+)

diff --git a/embark-org.el b/embark-org.el
new file mode 100644
index 00..30d76364af
--- /dev/null
+++ b/embark-org.el
@@ -0,0 +1,240 @@
+;;; embark-org.el --- Embark targets and actions for Org Mode  -*- 
lexical-binding: t; -*-
+
+;; Copyright (C) 2021  Omar Antolín Camarena
+
+;; Author: Omar Antolín Camarena 
+;; Keywords: convenience
+
+;; This program is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation, either version 3 of the License, or
+;; (at your option) any later version.
+
+;; This program is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+
+;; You should have received a copy of the GNU General Public License
+;; along with this program.  If not, see .
+
+;;; Commentary:
+
+;; This package configures the Embark package for use in Org Mode
+;; buffers. It teaches Embark a number of Org related targets and
+;; appropriate actions. Currently it has table cells, whole tables,
+;; and links. Targets to add: headings (Embark already has generic
+;; support for outlines, so we just nee to add Org specific actions),
+;; dates, source blocks, etc.
+
+;;; Code:
+
+(require 'embark)
+(require 'org)
+
+;;; Tables
+
+;; We define both cell and table targets
+
+(defun embark-org-target-cell ()
+  "Target contents of Org table cell at point."
+  (when (and (derived-mode-p 'org-mode) (org-at-table-p))
+`(org-table-cell
+  ,(save-excursion (string-trim (org-table-get-field)))
+  . (,(save-excursion (skip-chars-backward "^|") (point))
+ . ,(save-excursion (skip-chars-forward "^|") (point))
+
+(defun embark-org-target-table ()
+  "Target entire Org table at point."
+  (when (and (derived-mode-p 'org-mode) (org-at-table-p))
+`(org-table
+  ,(buffer-substring (org-table-begin) (org-table-end))
+  . (,(org-table-begin) . ,(org-table-end)
+
+(dolist (motion '(org-table-move-cell-up org-table-move-cell-down
+  org-table-move-cell-left org-table-move-cell-right))
+  (add-to-list 'embark-repeat-actions motion))
+
+(push 'embark--ignore-target
+  (alist-get 'org-table-edit-field embark-target-injection-hooks))
+
+(embark-define-keymap embark-org-table-cell-map
+  "Keymap for actions the current cells, column or row of an Org table."
+  (""org-table-move-cell-up)
+  (""  org-table-move-cell-down)
+  (""  org-table-move-cell-left)
+  ("" org-table-move-cell-right)
+  ("=" org-table-eval-formula)
+  ("e" org-table-edit-field)
+  ("g" org-table-recalculate))
+
+(embark-define-keymap embark-org-table-map
+  "Keymap for actions on entire Org table."
+  ("=" org-table-edit-formulas)
+  ("c" org-table-convert)
+  ("t" org-table-transpose-table-at-point)
+  ("f" org-table-follow-field-mode)
+  ("y" org-table-paste-rectangle)
+  ("d" org-table-toggle-formula-debugger)
+  ("i" org-table-iterate)
+  ("e" org-table-export))
+
+(add-to-list 'embark-target-finders #'embark-org-target-table)
+(add-to-list 'embark-keymap-alist '(org-table . embark-org-table-map))
+
+(add-to-list 'embark-target-finders #'embark-org-target-cell)
+(add-to-list 'embark-keymap-alist '(org-table-cell . 
embark-org-table-cell-map))
+
+;;; Links
+
+;; The link support has a slightly complicated design in order to
+;; achieve the following goals:
+
+;; 1. RET should simply be org-open-at-point
+
+;; 2. When the link is to a file, URL, email address or elisp
+;;expression or command, we want to offer the user actions for
+;;that underlying type.
+
+;; 3. Even in those cases, we still want some actions to apply to the
+;;entire link including description: actions to copy the link as
+;;markdown, or just the link description or target.
+
+;; So the strategy is as follows (illustrated with file links):
+
+;; - The target will be just the file, without the description and
+;;   also without the "file:" prefix nor the "::line-number or search"
+;;   suffix.  That way, file actions will correctly apply to it.
+
+;; - The type will not be 'file, but 'org-file-link that way we can
+;;   register a keymap for 'org-file-link that inherits from both
+;;   embark-org-link-map (with RET bound to org-open-at-point and a
+;;   few other generic link actions) and embark-file-map.
+
+;; - The commands to copy the link at point in some format will be
+;;   written as commands that act on the Org link at point.  This way
+;;   they are independently (plausibly) useful, and we circumvent the
+;;   problem that t

[elpa] externals/embark-consult updated (e9f0ea81a4 -> ac79525732)

2022-05-04 Thread ELPA Syncer
elpasync pushed a change to branch externals/embark-consult.

  from  e9f0ea81a4 Merge branch 'master' of 
https://github.com/oantolin/embark
  adds  ac79525732 Initial version of embark-org

No new revisions were added by this update.

Summary of changes:
 embark-org.el | 240 ++
 1 file changed, 240 insertions(+)
 create mode 100644 embark-org.el



[elpa] externals/pyim 34a1140ddb: * pyim-dhashcache.el (pyim-pymap): Removed.

2022-05-04 Thread ELPA Syncer
branch: externals/pyim
commit 34a1140ddb824b1be727fdf994c3680b07990af4
Author: Feng Shu 
Commit: Feng Shu 

* pyim-dhashcache.el (pyim-pymap): Removed.
---
 pyim-dhashcache.el | 1 -
 1 file changed, 1 deletion(-)

diff --git a/pyim-dhashcache.el b/pyim-dhashcache.el
index 6b939d255d..de82a50656 100644
--- a/pyim-dhashcache.el
+++ b/pyim-dhashcache.el
@@ -36,7 +36,6 @@
 (require 'cl-lib)
 (require 'async nil t)
 (require 'pyim-common)
-(require 'pyim-pymap)
 (require 'pyim-dcache)
 (require 'pyim-dict)
 (require 'pyim-scheme)
diff --git a/javaimp.el b/javaimp.el
index cd872d580c..455033bdb0 100644
--- a/javaimp.el
+++ b/javaimp.el
@@ -28,7 +28,8 @@
 ;; errors.  In addition, this module provides good Imenu support for
 ;; Java source files - with nesting and abstract methods in interfaces
 ;; and abstract classes.  It provides suitable functions to use as
-;; beginning-of-defun-function / end-of-defun-function as well.
+;; `beginning-of-defun-function' / `end-of-defun-function' /
+;; `add-log-current-defun-function' as well.
 ;;
 ;;
 ;;   Quick start:
@@ -95,8 +96,8 @@
 ;; Parsing is also used for Imenu support and for navigation commands.
 ;; As there's no minor/major mode (yet), you have to set
 ;; `imenu-create-index-function' and `beginning-of-defun-function' /
 ;; `end-of-defun-function' in major mode hook yourself.  See example
 ;; below.
 ;;
 ;; - `javaimp-imenu-use-sub-alists' - if non-nil then Imenu items are
 ;; presented in a nested fashion, instead of a flat list (the
@@ -132,6 +133,7 @@
 ;;
 ;; (setq beginning-of-defun-function #'javaimp-beginning-of-defun)
 ;; (setq end-of-defun-function #'javaimp-end-of-defun)
+;; (setq add-log-current-defun-function #'javaimp-add-log-current-defun)
 ;; (define-key java-mode-map (kbd "C-M-a") #'beginning-of-defun)
 ;; (define-key java-mode-map (kbd "C-M-e") #'end-of-defun)
 ;;
@@ -1001,6 +1003,28 @@ after this group of defuns."
  siblings)
 
 
+(defun javaimp-add-log-current-defun ()
+  "Function to be used as `add-log-current-defun-function'."
+  (save-excursion
+(save-restriction
+  (widen)
+  (let ((s (javaimp-parse-get-enclosing-scope
+(javaimp-scope-defun-p '(method anon-class
+names)
+(while s
+  (push (javaimp-scope-name s) names)
+  (setq s (javaimp-scope-parent s)))
+;; Omit top-level class name if there're other components,
+;; but only if it matches file name (it usually will).
+(when (and (> (length names) 1)
+   buffer-file-name
+   (equal (car names) (file-name-sans-extension
+   (file-name-nondirectory 
buffer-file-name
+  (setq names (cdr names)))
+(when names
+  (string-join names "."))
+
+
 
 ;; Misc
 



[elpa] externals/org d2a459d259: org-fold-check-before-invisible-edit: Be smart about editing at border

2022-05-04 Thread ELPA Syncer
branch: externals/org
commit d2a459d2596a0cfb1389207b117533389fa59e0f
Author: Ihor Radchenko 
Commit: Ihor Radchenko 

org-fold-check-before-invisible-edit: Be smart about editing at border

*
lisp/org-fold.el (org-fold-check-before-invisible-edit--text-properties):
Consider `border-and-ok-direction' value when deciding whether to
throw an error and reveal the fold.  Never throw an error when editing
at border without affecting the text inside.

Fixes https://orgmode.org/list/m2ilqle995@gmail.com
---
 lisp/org-fold.el | 15 ++-
 1 file changed, 10 insertions(+), 5 deletions(-)
@@ -95,8 +96,8 @@
 ;; As there's no minor/major mode (yet), you have to set
 ;; `imenu-create-index-function' and `beginning-of-defun-function' /
-;; `end-of-defun-function' in major mode hook yourself.  See example
-;; below.
+;; `end-of-defun-function' / `add-log-current-defun-function' in major
+;; mode hook yourself.  See example below.
 ;;
 ;; - `javaimp-imenu-use-sub-alists' - if non-nil then Imenu items are
